@@ -267,7 +267,7 @@ class Runtime(object):
         self.copy_files(destdir)
 
         # data directories from modulefinder
-        for name, (src, recursive) in self.mf._data_directories.items():
+        for name, (src, recursive) in self.mf.data_directories():
             if recursive:
                 dst = os.path.join(destdir, name)
                 if os.path.isdir(dst):
@@ -278,7 +278,7 @@ class Runtime(object):
                 raise RuntimeError("not yet supported")
 
         # data files from modulefinder
-        for name, src in self.mf._data_files.items():
+        for name, src in self.mf.data_files():
             dst = os.path.join(destdir, name)
             os.makedirs(os.path.dirname(dst), exist_ok=True)
             shutil.copy2(src, dst)
@@ -481,6 +481,12 @@ class Runtime(object):
                 marshal.dump(code, stream)
                 arc.writestr(path, stream.getvalue())
 
+        # data files to be zipped from modulefinder
+        for name, src in self.mf.data_files_to_zip():
+            if self.options.verbose > 1:
+                print("Add data file %s to %s" % (name, libpath))
+            arc.write(src, name)
+
         if self.options.bundle_files == 0:
             # put everything into the arc
             files = self.mf.all_dlls()
