@@ -15,7 +15,7 @@ HMODULE LoadLibraryA(LPCSTR)
 HMODULE GetModuleHandleA(LPCSTR)
 BOOL FreeLibrary(HMODULE)
 FARPROC GetProcAddress(HMODULE, LPCSTR)
-
+BOOL GetModuleHandleExW(DWORD, LPCWSTR, HMODULE *);
 
 MemoryModule API:
 =================
@@ -24,7 +24,7 @@ HMEMORYMODULE MemoryLoadLibrary(void *)
 void MemoryFreeLibrary(HMEMORYMODULE)
 FARPROC MemoryGetProcAddress(HMEMORYMODULE, LPCSTR)
 
-HMEMORYMODULE MemoryLoadLibrayEx(void *,
+HMEMORYMODULE MemoryLoadLibraryEx(void *,
                                  load_func, getproc_func, free_func, userdata)
 
 (there are also some resource functions which are not used here...)
@@ -36,8 +36,9 @@ HMODULE MyLoadLibrary(LPCSTR, void *, userdata)
 HMODULE MyGetModuleHandle(LPCSTR)
 BOOL MyFreeLibrary(HMODULE)
 FARPROC MyGetProcAddress(HMODULE, LPCSTR)
+BOOL WINAPI MyGetModuleHandleExW(DWORD, LPCWSTR, HMODULE *)
 
- */
+*/
 
 /****************************************************************
  * A linked list of loaded MemoryModules.
@@ -163,9 +164,10 @@ static HCUSTOMMODULE _LoadLibrary(LPCSTR filename, void *userdata)
 //		PyObject *res = PyObject_CallFunction(findproc, "s", filename);
 		PyObject *res = CallFindproc(findproc, filename);
 		if (res && PyBytes_AsString(res)) {
-			result = MemoryLoadLibraryEx(PyBytes_AsString(res),
-						     _LoadLibrary, _GetProcAddress, _FreeLibrary,
-						     userdata);
+			result = MemoryLoadLibraryEx(PyBytes_AsString(res), PyBytes_GET_SIZE(res),
+				MemoryDefaultAlloc, MemoryDefaultFree,
+				_LoadLibrary, _GetProcAddress, _FreeLibrary,
+				userdata);
 			Py_DECREF(res);
 			if (result) {
 				lib = _AddMemoryModule(filename, result);
@@ -202,14 +204,15 @@ HMODULE MyGetModuleHandle(LPCSTR name)
 	//return GetModuleHandle(name);
 }
 
-HMODULE MyLoadLibrary(LPCSTR name, void *bytes, void *userdata)
+HMODULE MyLoadLibrary(LPCSTR name, void *bytes, size_t size, void *userdata)
 {
 	if (userdata) {
 		HCUSTOMMODULE mod = _LoadLibrary(name, userdata);
 		if (mod)
 			return mod;
 	} else if (bytes) {
-		HCUSTOMMODULE mod = MemoryLoadLibraryEx(bytes,
+		HCUSTOMMODULE mod = MemoryLoadLibraryEx(bytes, size,
+							MemoryDefaultAlloc, MemoryDefaultFree,
 							_LoadLibrary,
 							_GetProcAddress,
 							_FreeLibrary,
@@ -235,6 +238,15 @@ BOOL MyFreeLibrary(HMODULE module)
 	}
 }
 
+BOOL WINAPI MyGetModuleHandleExW(DWORD flags, LPCWSTR modname, HMODULE *pmodule)
+{
+	if (flags & GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS && pmodule != NULL) {
+		*pmodule = GetModuleHandle(NULL);
+		return TRUE;
+	}
+	return GetModuleHandleExW(flags, modname, pmodule);
+}
+
 FARPROC MyGetProcAddress(HMODULE module, LPCSTR procname)
 {
 	FARPROC proc;
@@ -244,6 +256,8 @@ FARPROC MyGetProcAddress(HMODULE module, LPCSTR procname)
 	else {
 		SetLastError(0);
 		proc = GetProcAddress(module, procname);
+		if (proc == &GetModuleHandleExW)
+			proc = (FARPROC)MyGetModuleHandleExW;
 	}
 	return proc;
 }
